# Project Description

BuildTools is a collection of scripts that supports UO's Network and Telecom Services team (NTS) continuous integration and deployment solutions. 

[![PyPI version](https://badge.fury.io/py/ntsbuildtools.svg)](https://badge.fury.io/py/ntsbuildtools)

This documentation is split into the following sections:

* [User Guide](user-guide.md): Review this if you want to use BuildTools CLI yourself.
* [Software Design](software-design/_overview.md): If you are adding features to BuildTools, it is wise to review-and-update the relevant software design documents.
* [Deployment documentation](jenkins-cicd.md): Review this if you need to deploy a new version of BuildTools to PyPI. (via a private Jenkins CICD pipeline).


## MkDocs 

This `docs/` directory is best viewed as a simple web site via MkDocs.
For full documentation, see [mkdocs.org](https://www.mkdocs.org).

* `mkdocs serve` - Start the live-reloading docs server locally.
* `mkdocs help` - Show help info for mkdocs.
